==> haskell-enummapset-0.7.3.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enummapset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 enummapset
version:              0.7.3.0
visibility:           public
id:                   enummapset-0.7.3.0-EwvXonk1V9ImNmi3MXCRa
key:                  enummapset-0.7.3.0-EwvXonk1V9ImNmi3MXCRa
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Michal Terepeta and others
homepage:             https://github.com/Mikolaj/enummapset
synopsis:             IntMap and IntSet with Enum keys/elements.
description:
    This package contains simple wrappers around '\''Data.IntMap'\'' and
    '\''Data.IntSet'\'' with '\''Enum'\'' keys and elements respectively.
    Especially useful for '\''Int'\''s wrapped with `newtype`.

category:             Data Structures
abi:                  1bca6a4bf00b5a017c8a39efce9f3484
exposed:              True
exposed-modules:
    Data.EnumMap Data.EnumMap.Lazy Data.EnumMap.Strict Data.EnumSet

hidden-modules:       Data.EnumMap.Base
import-dirs:          /usr/lib/ghc-9.2.8/site-local/enummapset-0.7.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/enummapset-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enummapset
hs-libraries:         HSenummapset-0.7.3.0-EwvXonk1V9ImNmi3MXCRa
depends:
    aeson-2.1.2.1-3lugcDour1r4V4jv6ZKvkq base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1

haddock-interfaces:   /usr/share/doc/haskell-enummapset/html/enummapset.haddock
haddock-html:         /usr/share/doc/haskell-enummapset/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enummapset-0.7.3.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enummapset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 enummapset
version:              0.7.3.0
visibility:           public
id:                   enummapset-0.7.3.0-9tSBHH6qARh3LHROxU1Y15
key:                  enummapset-0.7.3.0-9tSBHH6qARh3LHROxU1Y15
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Michal Terepeta and others
homepage:             https://github.com/Mikolaj/enummapset
synopsis:             IntMap and IntSet with Enum keys/elements.
description:
    This package contains simple wrappers around '\''Data.IntMap'\'' and
    '\''Data.IntSet'\'' with '\''Enum'\'' keys and elements respectively.
    Especially useful for '\''Int'\''s wrapped with `newtype`.

category:             Data Structures
abi:                  0d8965c2687876a37b012b6f445b8347
exposed:              True
exposed-modules:
    Data.EnumMap Data.EnumMap.Lazy Data.EnumMap.Strict Data.EnumSet

hidden-modules:       Data.EnumMap.Base
import-dirs:          /usr/lib/ghc-9.2.8/site-local/enummapset-0.7.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/enummapset-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enummapset
hs-libraries:         HSenummapset-0.7.3.0-9tSBHH6qARh3LHROxU1Y15
depends:
    aeson-2.1.2.1-5xA96pEAe1OF80YjsNpBtK base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1

haddock-interfaces:   /usr/share/doc/haskell-enummapset/html/enummapset.haddock
haddock-html:         /usr/share/doc/haskell-enummapset/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
